@@ -9,9 +9,12 @@ from .message import MessageHandler
 class TextHandler(ext.MessageHandler[PTBContext], Handler[TextContext]):
     filters = MessageHandler.filters & ext.filters.TEXT
 
-    def __init__(self, callback: TextCallback) -> None:
+    def __init__(self, callback: TextCallback, button: str | None = None) -> None:
         self._callback = callback
-        super().__init__(self.filters, self.handle)
+        filters = self.filters
+        if button:
+            filters &= ext.filters.Text([button])
+        super().__init__(filters, self.handle)
 
     def make_context(self, raw: PTBContext, update: Update) -> TextContext:
         return TextContext(raw, update)
