@@ -1,7 +1,7 @@
 import warnings
 
 from telegram.constants import ParseMode
-from telegram.ext import Application, Defaults
+from telegram.ext import Application, Defaults, PicklePersistence
 from telegram.warnings import PTBUserWarning
 
 from .ptb_types import PTBHandler
@@ -25,10 +25,11 @@ DEFAULTS = Defaults(
 
 
 class App:
-    def __init__(self, token: str) -> None:
+    def __init__(self, token: str, storage_path: str) -> None:
         builder = Application.builder()
         builder.token(token).defaults(DEFAULTS)
         builder.concurrent_updates(True)  # noqa: FBT003
+        builder.persistence(PicklePersistence(storage_path))
         self.raw = builder.build()
 
     def run(self, handler: PTBHandler) -> None:
