@@ -1,4 +1,3 @@
-from .aliases import PTBCallback, PTBContext, PTBHandler, ReplyMarkup
 from .bot import Bot
 from .chat import Chat
 from .message import Message
@@ -13,8 +12,4 @@ __all__ = [
     "Query",
     "Update",
     "Message",
-    "PTBHandler",
-    "PTBContext",
-    "ReplyMarkup",
-    "PTBCallback",
 ]
